(function($) {
  Drupal.behaviors.mediamosa_sb_uvt_form = {
    attach: function (context, settings) {
      $('.form-item-retention').change(function() {

	var years = 1;
	var years_val = $('input:radio[name=retention]:checked', '#mediamosa-sb-asset-upload-steps-form').val();
	if (typeof years_val === "undefined") {
	  years_val = $('input:radio[name=retention]:checked', '#mediamosa-sb-asset-edit-metadata-form').val();
	}
	if (typeof years_val !== "undefined") {
	  years = years_val.charAt(0);
	}
	else {
	  years = 1;
	}
	created = $('input:hidden[name=now]').val();
	var parts = created.split('-');
	// new Date(year, month [, day [, hours[, minutes[, seconds[, ms]]]]])
	var retention_date = new Date(parts[2], parts[1], parts[0]); // Note: months are 0-based
	var day = retention_date.getDate();
	if (day < 9) {
	  day = '0' + day;
	}
	var month = retention_date.getMonth();
	if (month < 9) {
	  month = '0' + month;
	}
        var dateString = day + "-" + month + "-" +
	    (retention_date.getFullYear() + parseInt(years, 10));
	$('#edit-retention-date-text').html(dateString);
      });
    }
  };
})(jQuery);
